@@ -128,12 +128,14 @@ class powerswitch:
         start_status=self.status(outlet)
         if start_status == 'Off':
           return False
-        if start_status != 'Unknown':
-          self.off(outlet)
-          time.sleep(CYCLETIME)
-          self.on(outlet)
-        else:
+        if start_status == 'Unknown':
           return True
+        else:
+          if self.off(outlet):
+            return True
+          time.sleep(CYCLETIME)
+          if self.on(outlet):
+            return True
         return self.status(outlet) != start_status
     def statuslist(self):
         """ Return the status of all outlets in a list, 
